Struct XdgWmBase
pub struct XdgWmBase { /* private fields */ }wayland and Linux only.Expand description
create desktop-style surfaces
The xdg_wm_base interface is exposed as a global object enabling clients to turn their wl_surfaces into windows in a desktop environment. It defines the basic functionality needed for clients and the compositor to create windows that can be dragged, resized, maximized, etc, as well as creating transient windows such as popup menus.
See also the Event enum for this interface.
Implementations
impl XdgWmBase
impl XdgWmBase
pub fn destroy(&self)
pub fn destroy(&self)
destroy xdg_wm_base
Destroy this xdg_wm_base object.
Destroying a bound xdg_wm_base object while there are surfaces still alive created by this xdg_wm_base object instance is illegal and will result in a defunct_surfaces error.
pub fn create_positioner<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> XdgPositioner
pub fn create_positioner<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> XdgPositioner
create a positioner object
Create a positioner object. A positioner object is used to position surfaces relative to some parent surface. See the interface description and xdg_surface.get_popup for details.
pub fn get_xdg_surface<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> XdgSurface
pub fn get_xdg_surface<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> XdgSurface
create a shell surface from a surface
This creates an xdg_surface for the given surface. While xdg_surface itself is not a role, the corresponding surface may only be assigned a role extending xdg_surface, such as xdg_toplevel or xdg_popup. It is illegal to create an xdg_surface for a wl_surface which already has an assigned role and this will result in a role error.
This creates an xdg_surface for the given surface. An xdg_surface is used as basis to define a role to a given surface, such as xdg_toplevel or xdg_popup. It also manages functionality shared between xdg_surface based surface roles.
See the documentation of xdg_surface for more details about what an xdg_surface is and how it is used.